# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: system.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csystem.proto\"\x14\n\x06NodeId\x12\n\n\x02id\x18\x01 \x01(\t\";\n\x04Link\x12\x0e\n\x06parent\x18\x02 \x01(\t\x12\x17\n\x04type\x18\x03 \x01(\x0e\x32\t.LinkType\x12\n\n\x02id\x18\x01 \x01(\x05\"9\n\nConnection\x12\x15\n\x06output\x18\x01 \x01(\x0b\x32\x05.Link\x12\x14\n\x05input\x18\x02 \x01(\x0b\x32\x05.Link\"h\n\x04Node\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x03 \x01(\t\x12\x10\n\x08\x63\x61llback\x18\x04 \x01(\t\x12 \n\x0b\x63onnections\x18\x05 \x03(\x0b\x32\x0b.Connection\"*\n\x06Recipe\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x05nodes\x18\x02 \x03(\x0b\x32\x05.Node\"\n\n\x08NoneArgs\"\x1f\n\rRequestStatus\x12\x0e\n\x06status\x18\x01 \x01(\x05\"4\n\x05Image\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"7\n\rNetworkConfig\x12&\n\tframework\x18\x01 \x01(\x0e\x32\x13.SuportedFrameWorks\"\x1f\n\x07Point2f\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\"*\n\x07Point3f\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"\'\n\x06Size2f\x12\x0e\n\x06height\x18\x01 \x01(\x02\x12\r\n\x05width\x18\x02 \x01(\x02\";\n\x04Rect\x12\x0e\n\x06height\x18\x01 \x01(\x05\x12\r\n\x05width\x18\x02 \x01(\x05\x12\t\n\x01x\x18\x03 \x01(\x05\x12\t\n\x01y\x18\x04 \x01(\x05\"?\n\x0bProbability\x12\r\n\x05\x63lass\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bprobability\x18\x03 \x01(\x02\"6\n\x07Network\x12\x0b\n\x03\x63\x66g\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x01(\t\x12\x0f\n\x07weights\x18\x03 \x01(\t\"\x9a\x01\n\x08Settings\x12\x0e\n\x06\x64river\x18\x01 \x01(\x05\x12\x14\n\x0c\x65nable_tiles\x18\x02 \x01(\x08\x12\x1a\n\x12include_percentage\x18\x04 \x01(\x08\x12\x0b\n\x03nms\x18\x05 \x01(\x02\x12\x1a\n\x12output_redirection\x18\x06 \x01(\x08\x12\x10\n\x08snapping\x18\x07 \x01(\x08\x12\x11\n\tthreshold\x18\x08 \x01(\x02\"(\n\tTimestamp\x12\r\n\x05\x65poch\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\"\xf5\x01\n\nPrediction\x12\'\n\x11\x61ll_probabilities\x18\x01 \x03(\x0b\x32\x0c.Probability\x12\x12\n\nbest_class\x18\x02 \x01(\x05\x12\x18\n\x10\x62\x65st_probability\x18\x03 \x01(\x02\x12\x0c\n\x04name\x18\x04 \x01(\t\x12 \n\x0eoriginal_point\x18\x05 \x01(\x0b\x32\x08.Point2f\x12\x1e\n\roriginal_size\x18\x06 \x01(\x0b\x32\x07.Size2f\x12\x11\n\tobject_id\x18\x07 \x01(\x04\x12\x18\n\x10prediction_index\x18\x08 \x01(\x05\x12\x13\n\x04rect\x18\t \x01(\x0b\x32\x05.Rect\"L\n\x05Tiles\x12\x0e\n\x06height\x18\x01 \x01(\x05\x12\x12\n\nhorizontal\x18\x02 \x01(\x05\x12\x10\n\x08vertical\x18\x03 \x01(\x05\x12\r\n\x05width\x18\x04 \x01(\x05\"\xd1\x01\n\x04\x46ile\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x10\n\x08\x64uration\x18\x02 \x01(\t\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12\x17\n\x0foriginal_height\x18\x04 \x01(\x05\x12\x16\n\x0eoriginal_width\x18\x05 \x01(\x05\x12\x1f\n\nprediction\x18\x06 \x03(\x0b\x32\x0b.Prediction\x12\x16\n\x0eresized_height\x18\x07 \x01(\x05\x12\x15\n\rresized_width\x18\x08 \x01(\x05\x12\x15\n\x05tiles\x18\t \x01(\x0b\x32\x06.Tiles\"}\n\x0fInferenceResult\x12\x13\n\x04\x66ile\x18\x01 \x03(\x0b\x32\x05.File\x12\x19\n\x07network\x18\x02 \x01(\x0b\x32\x08.Network\x12\x1b\n\x08settings\x18\x03 \x01(\x0b\x32\t.Settings\x12\x1d\n\ttimestamp\x18\x04 \x01(\x0b\x32\n.Timestamp\"&\n\x06Object\x12\x1c\n\ncoordinate\x18\x01 \x01(\x0b\x32\x08.Point3f\"Q\n\x13WorldMappingRequest\x12\x15\n\x05image\x18\x01 \x01(\x0b\x32\x06.Image\x12#\n\tinference\x18\x02 \x01(\x0b\x32\x10.InferenceResult\".\n\x12WorldMappingResult\x12\x18\n\x07objects\x18\x01 \x03(\x0b\x32\x07.Object\"/\n\x0c\x41xisTemplate\x12\t\n\x01x\x18\x01 \x01(\t\x12\t\n\x01y\x18\x02 \x01(\t\x12\t\n\x01z\x18\x03 \x01(\t\"G\n\x15\x63onfigureStateRequest\x12\x1b\n\x04\x61xis\x18\x01 \x01(\x0b\x32\r.AxisTemplate\x12\x11\n\tactuators\x18\x02 \x03(\x08\"F\n\x14\x63onfigureStateResult\x12\x1b\n\x04\x61xis\x18\x01 \x01(\x0b\x32\r.AxisTemplate\x12\x11\n\tactuators\x18\x02 \x03(\x08\"7\n\x12updateStateRequest\x12!\n\x04info\x18\x01 \x01(\x0b\x32\x13.WorldMappingResult\"6\n\x11updateStateResult\x12!\n\x04info\x18\x01 \x01(\x0b\x32\x13.WorldMappingResult*!\n\x08LinkType\x12\n\n\x06OUTPUT\x10\x00\x12\t\n\x05INPUT\x10\x01*7\n\x12SuportedFrameWorks\x12\x0b\n\x07\x64\x61rknet\x10\x00\x12\n\n\x06opencv\x10\x01\x12\x08\n\x04rknn\x10\x02\x32l\n\x0bNodeManager\x12\x1d\n\raddRecipeNode\x12\x05.Node\x1a\x05.Node\x12\x1c\n\nremoveNode\x12\x07.NodeId\x1a\x05.Node\x12 \n\nloadRecipe\x12\x07.Recipe\x1a\t.NoneArgs2+\n\x06\x43\x61mera\x12!\n\x0ctake_picture\x12\t.NoneArgs\x1a\x06.Image2l\n\x0fObjectDetection\x12*\n\x0emake_inference\x12\x06.Image\x1a\x10.InferenceResult\x12-\n\x0bloadNetWork\x12\x0e.NetworkConfig\x1a\x0e.RequestStatus2S\n\x11ObjectPositioning\x12>\n\x11make_worldmapping\x12\x14.WorldMappingRequest\x1a\x13.WorldMappingResult2\x83\x01\n\x07Machine\x12?\n\x0e\x63onfigureState\x12\x16.configureStateRequest\x1a\x15.configureStateResult\x12\x37\n\x0bupdateState\x12\x13.updateStateRequest\x1a\x13.WorldMappingResultb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'system_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LINKTYPE']._serialized_start=2106
  _globals['_LINKTYPE']._serialized_end=2139
  _globals['_SUPORTEDFRAMEWORKS']._serialized_start=2141
  _globals['_SUPORTEDFRAMEWORKS']._serialized_end=2196
  _globals['_NODEID']._serialized_start=16
  _globals['_NODEID']._serialized_end=36
  _globals['_LINK']._serialized_start=38
  _globals['_LINK']._serialized_end=97
  _globals['_CONNECTION']._serialized_start=99
  _globals['_CONNECTION']._serialized_end=156
  _globals['_NODE']._serialized_start=158
  _globals['_NODE']._serialized_end=262
  _globals['_RECIPE']._serialized_start=264
  _globals['_RECIPE']._serialized_end=306
  _globals['_NONEARGS']._serialized_start=308
  _globals['_NONEARGS']._serialized_end=318
  _globals['_REQUESTSTATUS']._serialized_start=320
  _globals['_REQUESTSTATUS']._serialized_end=351
  _globals['_IMAGE']._serialized_start=353
  _globals['_IMAGE']._serialized_end=405
  _globals['_NETWORKCONFIG']._serialized_start=407
  _globals['_NETWORKCONFIG']._serialized_end=462
  _globals['_POINT2F']._serialized_start=464
  _globals['_POINT2F']._serialized_end=495
  _globals['_POINT3F']._serialized_start=497
  _globals['_POINT3F']._serialized_end=539
  _globals['_SIZE2F']._serialized_start=541
  _globals['_SIZE2F']._serialized_end=580
  _globals['_RECT']._serialized_start=582
  _globals['_RECT']._serialized_end=641
  _globals['_PROBABILITY']._serialized_start=643
  _globals['_PROBABILITY']._serialized_end=706
  _globals['_NETWORK']._serialized_start=708
  _globals['_NETWORK']._serialized_end=762
  _globals['_SETTINGS']._serialized_start=765
  _globals['_SETTINGS']._serialized_end=919
  _globals['_TIMESTAMP']._serialized_start=921
  _globals['_TIMESTAMP']._serialized_end=961
  _globals['_PREDICTION']._serialized_start=964
  _globals['_PREDICTION']._serialized_end=1209
  _globals['_TILES']._serialized_start=1211
  _globals['_TILES']._serialized_end=1287
  _globals['_FILE']._serialized_start=1290
  _globals['_FILE']._serialized_end=1499
  _globals['_INFERENCERESULT']._serialized_start=1501
  _globals['_INFERENCERESULT']._serialized_end=1626
  _globals['_OBJECT']._serialized_start=1628
  _globals['_OBJECT']._serialized_end=1666
  _globals['_WORLDMAPPINGREQUEST']._serialized_start=1668
  _globals['_WORLDMAPPINGREQUEST']._serialized_end=1749
  _globals['_WORLDMAPPINGRESULT']._serialized_start=1751
  _globals['_WORLDMAPPINGRESULT']._serialized_end=1797
  _globals['_AXISTEMPLATE']._serialized_start=1799
  _globals['_AXISTEMPLATE']._serialized_end=1846
  _globals['_CONFIGURESTATEREQUEST']._serialized_start=1848
  _globals['_CONFIGURESTATEREQUEST']._serialized_end=1919
  _globals['_CONFIGURESTATERESULT']._serialized_start=1921
  _globals['_CONFIGURESTATERESULT']._serialized_end=1991
  _globals['_UPDATESTATEREQUEST']._serialized_start=1993
  _globals['_UPDATESTATEREQUEST']._serialized_end=2048
  _globals['_UPDATESTATERESULT']._serialized_start=2050
  _globals['_UPDATESTATERESULT']._serialized_end=2104
  _globals['_NODEMANAGER']._serialized_start=2198
  _globals['_NODEMANAGER']._serialized_end=2306
  _globals['_CAMERA']._serialized_start=2308
  _globals['_CAMERA']._serialized_end=2351
  _globals['_OBJECTDETECTION']._serialized_start=2353
  _globals['_OBJECTDETECTION']._serialized_end=2461
  _globals['_OBJECTPOSITIONING']._serialized_start=2463
  _globals['_OBJECTPOSITIONING']._serialized_end=2546
  _globals['_MACHINE']._serialized_start=2549
  _globals['_MACHINE']._serialized_end=2680
# @@protoc_insertion_point(module_scope)
